Kite Manual
===========

Kite is an open source toolbox for processing and analysing InSAR surface displacement maps.


Features
--------

.. raw:: html

    <div class="keywords">
        <span>InSAR displacement analysis</span>
        <span>displacement processing</span>
        <span>quadtree calculation and parametrisation</span>
        <span>InSAR noise analysis</span>
        <span>covariance calculation</span>
        <span>error estimation</span>
    </div>

Overview
--------

.. toctree::
    :maxdepth: 2

    installation
    quickstart
    examples/index
    tools/index
    reference/index
    contributing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
